
# Slot: prefix_reference


A URI associated with a given prefix

URI: [linkml:prefix_reference](https://w3id.org/linkml/prefix_reference)


## Domain and Range

[Prefix](Prefix.md) &#8594;  <sub>1..1</sub> [Uri](types/Uri.md)

## Parents


## Children


## Used by

 * [Prefix](Prefix.md)
